@@ -1,18 +1,16 @@
 import uuid
 import json
 import subprocess
-from typing import Dict
 import socket
 import tempfile
-import shutil
-import os
 import sys
 from . import messages
 import tarfile
 
-def working(hiveAddress:str):
-    HOST, PORT = hiveAddress.split(":")
-    PORT = int(PORT)
+
+def working(hive_address:str):
+    HOST, p = hive_address.split(":")
+    PORT = int(p)
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.settimeout(None)
     try:
